@@ -10,6 +10,17 @@ module R10K
 
         include R10K::Action::Deploy::DeployHelpers
 
+        attr_reader :force
+
+        def initialize(opts, argv, settings = nil)
+          settings ||= {}
+
+          super
+
+          # @force here is used to make it easier to reason about
+          @force = !@no_force
+        end
+
         def call
           @visit_ok = true
 
@@ -50,14 +61,14 @@ module R10K
         def visit_module(mod)
           if @argv.include?(mod.name)
             logger.info _("Deploying module %{mod_path}") % {mod_path: mod.path}
-            mod.sync
+            mod.sync(force: @force)
           else
             logger.debug1(_("Only updating modules %{modules}, skipping module %{mod_name}") % {modules: @argv.inspect, mod_name: mod.name})
           end
         end
 
         def allowed_initialize_opts
-          super.merge(environment: true)
+          super.merge(environment: true, :'no-force' => :self)
         end
       end
     end
