@@ -6,7 +6,7 @@ require 'r10k/forge/module_release'
 
 require 'pathname'
 require 'fileutils'
-require 'puppet_forge'
+require 'puppet_forge/util'
 
 class R10K::Module::Forge < R10K::Module::Base
 
@@ -17,7 +17,7 @@ class R10K::Module::Forge < R10K::Module::Base
   end
 
   def self.valid_version?(expected_version)
-    expected_version == :latest || expected_version.nil? || SemanticPuppet::Version.valid?(expected_version)
+    expected_version == :latest || expected_version.nil? || PuppetForge::Util.version_valid?(expected_version)
   end
 
   # @!attribute [r] metadata
@@ -88,6 +88,14 @@ class R10K::Module::Forge < R10K::Module::Base
     status == :insync
   end
 
+  def deprecated?
+    begin
+      @v3_module.fetch && @v3_module.has_attribute?('deprecated_at') && !@v3_module.deprecated_at.nil?
+    rescue Faraday::ResourceNotFound => e
+      raise PuppetForge::ReleaseNotFound, _("The module %{title} does not exist on %{url}.") % {title: @title, url: PuppetForge::V3::Release.conn.url_prefix}, e.backtrace
+    end
+  end
+
   # Determine the status of the forge module.
   #
   # @return [Symbol] :absent If the directory doesn't exist
@@ -129,6 +137,10 @@ class R10K::Module::Forge < R10K::Module::Base
   end
 
   def install
+    if deprecated?
+      logger.warn "Puppet Forge module '#{@v3_module.slug}' has been deprecated, visit https://forge.puppet.com/#{@v3_module.slug.tr('-','/')} for more information."
+    end
+
     parent_path = @path.parent
     if !parent_path.exist?
       parent_path.mkpath
