@@ -51,6 +51,10 @@ module R10K
               :desc => "An optional proxy server to use when interacting with Git sources via HTTP(S).",
               :default => :inherit,
             }),
+            
+            Definition.new(:ignore_branch_prefixes, {
+              :desc => "Array of strings used to prefix branch names that will not be deployed as environments.",
+            }),
           ])
         },
         {
@@ -84,6 +88,26 @@ module R10K
             end
           end
         }),
+
+        EnumDefinition.new(:purge_levels, {
+          :desc => "Controls how aggressively r10k will purge unmanaged content from the target directory. Should be a list of values indicating at what levels unmanaged content should be purged. Options are 'deployment', 'environment', and 'puppetfile'. For backwards compatibility, the default is ['deployment', 'puppetfile'].",
+          :multi => true,
+          :enum => [:deployment, :environment, :puppetfile],
+          :default => [:deployment, :puppetfile],
+          :normalize => lambda do |input|
+            if input.respond_to?(:collect)
+              input.collect { |val| val.to_sym }
+            else
+              # Convert single values to a list of one symbolized value.
+              [input.to_sym]
+            end
+          end,
+        }),
+
+        Definition.new(:purge_whitelist, {
+          :desc => "A list of filename patterns to be excluded from any purge operations. Patterns are matched relative to the root of each deployed environment, if you want a pattern to match recursively you need to use the '**' glob in your pattern. Basic shell style globs are supported.",
+          :default => [],
+        }),
       ])
     end
 
